@@ -62,6 +62,7 @@ alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_SCOPE_FK;
 alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_INST_FK;
 alter table NOVA_BPEL_EXEC drop constraint FKF01EB0C8B2F982DE;
 alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_PARENT_FK;
+alter table NOVA_BPEL_PROCESS drop constraint FK3FB3AAB887A9CDF8;
 alter table NOVA_BPEL_PROCESS drop constraint FK3FB3AAB8398073E8;
 alter table NOVA_BPEL_PROCESS drop constraint FK3FB3AAB89A504866;
 alter table NOVA_BPEL_TESTS drop constraint FK14825CAA8DCEEF2D;
@@ -169,12 +170,12 @@ alter table NOVA_PL_RUNTIME drop constraint BPEL_SCOPE_PLK_FK;
 alter table NOVA_PROCESS drop constraint FK_PROCDEF_INITIAL;
 alter table NOVA_PROCESS drop constraint FK_PROCDEF_PROPS;
 alter table NOVA_PROCESS_START drop constraint FK85755F7FA088E666;
+alter table NOVA_PROCESS_START drop constraint FK85755F7F5F9F3677;
 alter table NOVA_PROCESS_START drop constraint FK85755F7F2857DEA8;
 alter table NOVA_PROPALIAS drop constraint FKF1CD045A64EEA1B7;
 alter table NOVA_PROPALIAS drop constraint FKF1CD045A2E48839;
 alter table NOVA_RECEIVER drop constraint BPEL_RECV_OP_KEY_FK;
 alter table NOVA_RECEIVER drop constraint FK1B0ED4A22857DEA8;
-alter table NOVA_REPLIER drop constraint BPEL_REPLIER_SCOPE_FK;
 alter table NOVA_REPLIER drop constraint BPEL_EXEC_REPLIERS_FK;
 alter table NOVA_REPLIER drop constraint BPEL_REPKEY_OP_KEY_FK;
 alter table NOVA_SCOPE_MESSEXS drop constraint SCOPE_MSG_EX_FK;
@@ -246,6 +247,7 @@ drop table CS_PROPERTIES_;
 drop table ELSEIF_DEF_;
 drop table FRM_PRT_DEF_;
 drop table FROM_TO_FULL;
+drop table INST_COUNT_;
 drop table INVOKE_IN_MSG_PART;
 drop table INVOKE_OUT_MSG_PART;
 drop table NOVA_ACTIVITY;
@@ -292,6 +294,7 @@ drop table NOVA_PLNKT_ROLES;
 drop table NOVA_PL_RUNTIME;
 drop table NOVA_PROCESS;
 drop table NOVA_PROCESS_START;
+drop table NOVA_PROC_COUNT;
 drop table NOVA_PROPALIAS;
 drop table NOVA_RECEIVER;
 drop table NOVA_REPLIER;
